% Compute the objective value of the IRP partitioning (i.e. cut) problem evaluated at the point estimator
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Inputs:  
% y:           n x 1 input vector to isotonic regression, e.g. observations
% estimator:   point estimator for isotonic regresson over entire group
% options:     same options as to IRP(.) function
% inds:        indices of observations in the group to be cut (for use when there are weights)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Outputs:  
% v:           n x 1 output vector of values to be used in objective of partitioning problem 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Modified by Ronny Luss, May 2011
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [v] = cut_value(y,estimator,options,inds)

switch options.weightedL2
    case 0
        v=2*(y-estimator); % L2 isotonic regression
    case 1
        v=2*(y-estimator).*options.weights(inds); % weighted L2 isotonic regression
end



