% Test IRP versus Mosek for L2 Isotonic Regression
% NOTE: on PC with 2.40 GHz proccessor and 3 GB RAM, the output was:
% Starting IRP.
% Done running IRP after 5.5598 seconds.
% Starting Mosek.
% Done running Mosek after 334.5707 seconds.

% Modify paths
addpath('C:/Program Files/Mosek/6/toolbox/r2007a');
addpath('..')
addpath('../subRoutines')

n=1000; % number of training observations
d=4;   % dimension
sigma=d;

rand('state',25);
randn('state',20);
% observation matrix
data=rand(n,d)*3;
% take y_i=prod_d(x_id)
y=ones(n,1);
for i=1:d
    y=y.*data(:,i);
end    
y=y+sigma*randn(n,1); % add noise N(0,sigma^2)

options=[];

disp('Start creating adjacency matrix for creating training data model.');tic;    
[A,ind_A,ind_original]=adjacency_matrix(data);
disp(['Done creating adjacency matrix after ',num2str(toc),' seconds.']);
y=y(ind_A);
data=data(ind_A,:);

disp('Starting IRP.');tic;    
[x1,cutInds,iter,violation_flag]=IRP(y,A,options);
disp(['Done running IRP after ',num2str(toc),' seconds.']);

% Solve with quadprog of Mosek
[I,J]=find(A);
m=length(I);
C=sparse(1:m,I,ones(m,1),m,n)-sparse(1:m,J,ones(m,1),m,n);
b=sparse(m,1);
H=2*eye(n);
f=-2*y;

options = [];
disp('Starting Mosek.');tic;    
[x2,temp,exitflag]=quadprog(H,f,C,b,[],[],[],[],[]);
disp(['Done running Mosek after ',num2str(toc),' seconds.']);